addWeak: Add Weak Mutation TYpes

addWeakR Documentation

Add Weak Mutation TYpes

Description

Restore Mutation Types that were initially excluded because a low number of total counts.

Usage

addWeak(
  mutationTypesToAddSet,
  processes_I,
  processesStd_I,
  Wall_I,
  genomeErrors_I,
  genomesReconstructed_I
)

Arguments

mutationTypesToAddSet

Set of mutations to restore

processes_I

Set of Mutational Processes

processesStd_I

Set of standard deviations of all Mutational Processes

Wall_I

Set of all W matrices previously extracted

genomeErrors_I

Set of all residuals

genomesReconstructed_I

Fitted Values according to the most likely Model

Details

This is one of the core functions included in the original mutSignatures R library, and in the WTSI MATLAB framework. This is an internal function.

Value

Output is the final result of the deconvolution process

Author(s)

Damiano Fantini, damiano.fantini@gmail.com

References

More information and examples about mutational signature analysis can be found here:

  1. Official website: http://www.mutsignatures.org

  2. More info and examples about the mutSignatures R library: https://www.data-pulse.com/dev_site/mutsignatures/

  3. Oncogene paper, Mutational Signatures Operative in Bladder Cancer: https://www.nature.com/articles/s41388-017-0099-6

  4. WTSI framework: https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3588146/


dami82/mutSignatures documentation built on Jan. 24, 2023, 12:21 a.m.