| getFwkParam | R Documentation |
Retrieve the list of parameters used for running a Mutation Signature Analysis.
getFwkParam(x, label) ## S4 method for signature 'mutFrameworkParams,character' getFwkParam(x, label)
x |
a mutFrameworkParams-class object |
label |
string, corresponding to the parameter name to extract |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.